#!/bin/bash
#
# Build all forms of the Booke.

if [ $# -lt 1 ]; then
    echo "Usage: makeAll.sh <booke dir name> [<booke dir name> ...]"
    exit 1
fi

makeABooke()
{
    # Print graphics.
    ./makeGraphics.sh "$1"

    # Normal graphics printed output.
    ./makeBookeTunePages.sh "$1"
    ./makeBooke.sh A4 "$1"
    ./makeBooke.sh Nook "$1"

    # Compact graphics printed output.
    ./makeBookeTunePages.sh --use-compact "$1"
    ./makeBooke.sh A5 "$1"
    ./makeBooklet.sh "$1"

    # Web output.
    ./makeWebGraphics.sh "$1"
    ./makeWebAudio.sh "$1"
    ./makeWeb.sh "$1" "$1" "$2"
}

makeATransposedBooke()
{
    # Print graphics.
    ./makeGraphics.sh "$1"

    # Normal graphics printed output.
    ./makeBookeTunePages.sh "$1"
    ./makeBooke.sh A4 "$1"
    ./makeBooke.sh Nook "$1"

    # Compact graphics printed output.
    ./makeBookeTunePages.sh --use-compact "$1"
    ./makeBooke.sh A5 "$1"
    ./makeBooklet.sh "$1"

    # Web output. Uses audio from main booke.
    ./makeWebGraphics.sh "$1"
    ./makeWeb.sh "$1" "$2" "$3"
}

makeASingleBooke()
{
    makeABooke $1

    ./makeCello.sh $1
    makeATransposedBooke $1-Cello $1 cello

    ./makeHornInF.sh $1
    makeATransposedBooke $1-HornInF $1 "horn in F"

    ./makeAltoRecorderCFingering.sh $1
    makeATransposedBooke $1-AltoRecorderCFingering $1 "alto recorder, C fingering"
}

makeBumperBooke()
{
    # This can only be used once all the other Bookes have been built.
    ./makeBooke.sh A4 "$@"
    ./makeBooke.sh A5 "$@"
    ./makeBooklet.sh "Bumper"
}

for booke in "$@"
do
    makeASingleBooke $booke
done
if [ $# -gt 1 ]; then
    makeBumperBooke "$@"
    cp Bumper*.pdf ./web
fi
